<?php

/**
 * @package         Google Structured Data
 * @version         5.1.2 Free
 *
 * @author          Tassos Marinos <info@tassos.gr>
 * @link            http://www.tassos.gr
 * @copyright       Copyright © 2022 Tassos Marinos All Rights Reserved
 * @license         GNU GPLv3 <http://www.gnu.org/licenses/gpl.html> or later
 */

namespace GSD\Schemas\Schemas;

// No direct access
defined('_JEXEC') or die;

use GSD\Helper;

class JobPosting extends \GSD\Schemas\Base
{
    /**
     * A key => value array with properties that needs to be renamed
     *
     * @var mixed
     */
    protected $rename_properties = [
        'locality'    => 'addressLocality',
        'region'      => 'addressRegion',
        'postal_code' => 'postalCode'
    ];

    /**
     * The HTML tags allowed to be used in certain schema properties, such as the headline and the description.
     *
     * @var mixed
     */
    protected $allowed_HTML_tags = '<p><br><ul><li><h1><h2><h3><h4><h5><strong><em><b>';

    /**
     * Class constructor
     *
     * @param JRegistry $data The schema properties
     */
    public function __construct($data = null)
    {
        parent::__construct($data);
        $this->descCharLimit = 0;
    }

    /**
     * Return all the schema properties
     *
     * @return JRegistry
     */
    public function getProperties()
    {
        $props = [
            'hiring_organization_logo' => Helper::absURL($this->data['hiring_organization_logo']),
            'valid_through'            => Helper::date($this->data['valid_through'], true),
            'salary'                   => strpos($this->data['salary'], '-') === false ? Helper::formatPrice($this->data['salary']) : explode('-', $this->data['salary']),
        ];

        $this->data->loadArray($props);

        return parent::getProperties();
    }
}